@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,12 +52,10 @@ package com.openexchange.configjump.generic;
 import java.util.Properties;
 import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReentrantLock;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.ServiceRegistration;
-
 import com.openexchange.configjump.ConfigJumpService;
 
 /**
@@ -66,7 +64,7 @@ import com.openexchange.configjump.ConfigJumpService;
  */
 public final class Services {
 
-    private static final Log LOG = LogFactory.getLog(Services.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(Services.class));
 
     private final BundleContext context;
 
@@ -75,7 +73,7 @@ public final class Services {
     private final Lock registrationLock = new ReentrantLock();
 
     /**
-     * Default constructor. 
+     * Default constructor.
      */
     public Services(final BundleContext context) {
         super();
